.. :changelog:

History
=======

0.1.1
-----

* Fix an installation bug

0.1.0
-----

* Django 1.7+ compatibility (moved South migrations module to `south_migrations`
  and added native Django `migrations` module - thanks to @smajda for that)

0.0.1
-----

* First release
